@@ -45,6 +45,7 @@
 #'   Buckland, D.R.Anderson, K.P. Burnham, J.L. Laake, D.L. Borchers, and L.
 #'   Thomas. Oxford University Press.
 #' @keywords Statistical Models
+#' @importFrom methods is
 ddf.trial.fi <- function(model, data, meta.data=list(), control=list(),
                          call="", method){
   #  NOTE: gams are only partially implemented
@@ -54,14 +55,9 @@ ddf.trial.fi <- function(model, data, meta.data=list(), control=list(),
   # dummy functions are removed after they are used so the real ones can be
   # used in the model fitting.
   glm <- function(formula,link="logit"){
-    if(class(formula)!="formula"){
-      if(class(try(as.formula(formula)))!="formula"){
-        stop("Invalid formula")
-      }
-    }else{
-      formula <- paste(as.character(formula),collapse="")
-    }
-    if(class(link)=="function"){
+    formula <- fixformula(formula)
+
+    if(is(link, "function")){
       link <- substitute(link)
     }
     link <- match.arg(link,c("logit"))
@@ -69,14 +65,9 @@ ddf.trial.fi <- function(model, data, meta.data=list(), control=list(),
   }
 
   gam <- function(formula,link="logit"){
-    if(class(formula)!="formula"){
-      if(class(try(as.formula(formula)))!="formula"){
-        stop("Invalid formula")
-      }
-    }else{
-      formula <- paste(as.character(formula),collapse="")
-    }
-    if(class(link)=="function"){
+    formula <- fixformula(formula)
+
+    if(is(link, "function")){
       link <- substitute(link)
     }
     link <- match.arg(link,c("logit"))
@@ -105,7 +96,7 @@ ddf.trial.fi <- function(model, data, meta.data=list(), control=list(),
   # Assign model values; this uses temporarily defined functions glm and gam
   modpaste <- paste(model)
   modelvalues <- try(eval(parse(text=modpaste[2:length(modpaste)])))
-  if(class(modelvalues)=="try-error"){
+  if(inherits(modelvalues, "try-error")){
     stop("Invalid model specification: ",model)
   }
   rm(glm,gam)
